@@ -5,10 +5,9 @@ import requests
 from requests.auth import AuthBase
 
 from qiniu import config
-from .auth import RequestsAuth
+import qiniu.auth
 from . import __version__
 
-
 _sys_info = '{0}; {1}'.format(platform.system(), platform.machine())
 _python_ver = platform.python_version()
 
@@ -19,7 +18,7 @@ _headers = {'User-Agent': USER_AGENT}
 
 
 def __return_wrapper(resp):
-    if resp.status_code != 200:
+    if resp.status_code != 200 or resp.headers.get('X-Reqid') is None:
         return None, ResponseInfo(resp)
     ret = resp.json() if resp.text != '' else {}
     return ret, ResponseInfo(resp)
@@ -35,12 +34,17 @@ def _init():
     _session = session
 
 
-def _post(url, data, files, auth):
+def _post(url, data, files, auth, headers=None):
     if _session is None:
         _init()
     try:
+        post_headers = _headers
+        if headers is not None:
+            for k, v in headers.items():
+                post_headers.update({k: v})
         r = _session.post(
-            url, data=data, files=files, auth=auth, headers=_headers, timeout=config.get_default('connection_timeout'))
+            url, data=data, files=files, auth=auth, headers=post_headers,
+            timeout=config.get_default('connection_timeout'))
     except Exception as e:
         return None, ResponseInfo(None, e)
     return __return_wrapper(r)
@@ -49,7 +53,7 @@ def _post(url, data, files, auth):
 def _get(url, params, auth):
     try:
         r = requests.get(
-            url, params=params, auth=RequestsAuth(auth) if auth is not None else None,
+            url, params=params, auth=qiniu.auth.RequestsAuth(auth) if auth is not None else None,
             timeout=config.get_default('connection_timeout'), headers=_headers)
     except Exception as e:
         return None, ResponseInfo(None, e)
@@ -74,7 +78,42 @@ def _post_file(url, data, files):
 
 
 def _post_with_auth(url, data, auth):
-    return _post(url, data, None, RequestsAuth(auth))
+    return _post(url, data, None, qiniu.auth.RequestsAuth(auth))
+
+
+def _post_with_auth_and_headers(url, data, auth, headers):
+    return _post(url, data, None, qiniu.auth.RequestsAuth(auth), headers)
+
+
+def _post_with_qiniu_mac(url, data, auth):
+    qn_auth = qiniu.auth.QiniuMacRequestsAuth(auth) if auth is not None else None
+    timeout = config.get_default('connection_timeout')
+
+    try:
+        r = requests.post(url, json=data, auth=qn_auth, timeout=timeout, headers=_headers)
+    except Exception as e:
+        return None, ResponseInfo(None, e)
+    return __return_wrapper(r)
+
+
+def _get_with_qiniu_mac(url, params, auth):
+    try:
+        r = requests.get(
+            url, params=params, auth=qiniu.auth.QiniuMacRequestsAuth(auth) if auth is not None else None,
+            timeout=config.get_default('connection_timeout'), headers=_headers)
+    except Exception as e:
+        return None, ResponseInfo(None, e)
+    return __return_wrapper(r)
+
+
+def _delete_with_qiniu_mac(url, params, auth):
+    try:
+        r = requests.delete(
+            url, params=params, auth=qiniu.auth.QiniuMacRequestsAuth(auth) if auth is not None else None,
+            timeout=config.get_default('connection_timeout'), headers=_headers)
+    except Exception as e:
+        return None, ResponseInfo(None, e)
+    return __return_wrapper(r)
 
 
 class ResponseInfo(object):
@@ -111,12 +150,14 @@ class ResponseInfo(object):
                     self.error = 'unknown'
                 else:
                     self.error = ret['error']
+            if self.req_id is None and self.status_code == 200:
+                self.error = 'server is not qiniu'
 
     def ok(self):
-        return self.status_code == 200
+        return self.status_code == 200 and self.req_id is not None
 
     def need_retry(self):
-        if self.__response is None:
+        if self.__response is None or self.req_id is None:
             return True
         code = self.status_code
         if (code // 100 == 5 and code != 579) or code == 996:
@@ -124,7 +165,7 @@ class ResponseInfo(object):
         return False
 
     def connect_failed(self):
-        return self.__response is None
+        return self.__response is None or self.req_id is None
 
     def __str__(self):
         return ', '.join(['%s:%s' % item for item in self.__dict__.items()])
